#!/bin/sh 

if [ ! -f gs3-setup.sh ]; then
    echo "You must run this script from within the Greenstone 3 home directory"
    exit 1
fi

source gs3-setup.sh

gsdl3home=$GSDL3HOME

#########################
# CHECK NECESSARY BITS
#########################
if test -z "$CVSROOT" ; then
  echo "You need to set the environment variable CVSROOT before running"
  echo "this script. Please use the same path that you used to check out"
  echo "the Greentone repository. If you are not using anonymous cvs, you"
  echo "also need to set the variable CVS_RSH to ssh."
  exit;
fi
 
############################
# GET INFO FROM USER
############################

# Prompt for the computer name
hostname="localhost"
echo ""
echo "Enter the full address of the host computer from which the greenstone"
echo "collections will be served, for example:"
echo "bob.greenstone.ac.nz"
echo "or press enter for default [Default = localhost]."
echo ""
printf "%s" "> "
read ans
if [ "$ans" != "" ] ; then
    hostname="$ans"
fi

# Prompt for the port number
portnumber="8080"
echo ""
echo "Enter the port number that the tomcat webserver will serve on,"
echo "or press enter for default [Default = 8080]."
echo ""
printf "%s" "> "
read ans
if [ "$ans" != "" ] ; then
    portnumber="$ans"
fi

#################################
# CHECKOUT ALL THE BITS FROM CVS
#################################

# firstly, remove unwanted directories
cvs update -dRP

# now check out extra bits
cd packages
if [ ! -d mgpp ]; then
    cvs co -P mgpp
fi
cd $gsdl3home

###############################
# SETUP TOMCAT
###############################

cd comms/jakarta/
# unpack tomcat and rename directory
if [ ! -d tomcat ]; then
    unzip jakarta-tomcat-4.1.30.zip
    mv jakarta-tomcat-4.1.30 tomcat
fi

#edit the tomcat setclasspath script to add our classpath
if [ ! -f ./tomcat/bin/setclasspath.sh.orig ]; then
    mv ./tomcat/bin/setclasspath.sh ./tomcat/bin/setclasspath.sh.orig
    cat ./tomcat/bin/setclasspath.sh.orig | sed 's,CLASSPATH=,CLASSPATH=\"$CLASSPATH\":,' > ./tomcat/bin/setclasspath.sh
fi

# copy the modified server.xml into tomcat
if [ ! -f ./tomcat/conf/server-withexamples.xml.config ]; then
    mv ./tomcat/conf/server.xml ./tomcat/conf/server-withexamples.xml.config
    cat server.xml.in | sed "s|@gsdl3home@|${gsdl3home}|" > ./tomcat/conf/server.xml
fi

# Edit the server.xml config file to set the port number
if [ "$portnumber" != "8080" ] ; then
    cat ./tomcat/conf/server.xml | sed "s|8080|${portnumber}|" > server.xml.tmp
    mv server.xml.tmp ./tomcat/conf/server.xml
fi

#make everyone happy by giving the right permissions to the shell scripts
chmod a+x ./tomcat/bin/*.sh

cd $gsdl3home

###############################
# SETUP SOAP 
###############################
cd comms/soap
# unpack soap and rename directory
if [ ! -d soap ]; then
    unzip soap-bin-2.3.1.zip
    mv soap-2_3_1 soap
    cp soap/lib/soap.jar $gsdl3home/lib/java
# move the localsite deployment description into the soap webapp - localsite comes predeployed
    cp DeployedServices.ds soap/webapps/soap/
    # disable soap by renaming the web.xml file
    mv ./soap/webapps/soap/WEB-INF/web.xml ./soap/webapps/soap/WEB-INF/web.xml.disabled
fi
cd $gsdl3home

#edit the SOAPServer config file
if [ ! -f ./resources/java/SOAPServer.cfg ]; then
    sed "s|@gsdl3home@|${gsdl3home}|" ./resources/java/SOAPServer.cfg.in > ./resources/java/SOAPServer.cfg
fi

################################
# SETUP MYSQL + SAMPLE DATABASES
################################

if [ ! -d packages/mysql/data ]; then
    cd packages/mysql
    unzip mysql-4.0.20-linux.zip
    mkdir var
    mkdir var/log
    chmod 777 var var/log    

    ./scripts/mysql_install_db --datadir=./data --basedir=. --user=root --force
    ./bin/mysqld_safe --user=root --datadir=./data --basedir=. --pid_file=gsdl3.pid --socket=/tmp/mysql.sock --err-log=./var/log/mysql.log &
    sleep 2
    ./bin/mysql --user=root --execute="GRANT SELECT,INSERT,DELETE,UPDATE,DROP,CREATE ON *.* TO gsdl3admin@localhost;"
    ./bin/mysql --user=root --execute="GRANT SELECT,INSERT,DELETE,UPDATE,DROP,CREATE ON *.* TO gsdl3admin@'%';"
    ./bin/mysql --user=root --execute="GRANT SELECT ON *.* TO gsdl3reader@localhost;"
    
    # set up any sample collections databases
    #gs3mgdemo
    ./bin/mysql --user=root --execute="create database localsite_gs3mgdemo;"
    ./bin/mysql --user=root localsite_gs3mgdemo < $gsdl3home/web/sites/localsite/collect/gs3mgdemo/mysqldatadump.sql

    ./bin/mysqladmin --user=root --socket=/tmp/mysql.sock shutdown
    cd  $gsdl3home
fi

#################################
# WEB.XML FILE
#################################
# Edit the web/WEB-INF/web.xml to set gsdl3home
if [ ! -f ./web/WEB-INF/web.xml ]; then
    sed "s|@gsdl3home@|${gsdl3home}|" ./web/WEB-INF/web.xml.in > ./web/WEB-INF/web.xml
fi

#################################
# SITE CONFIG FILES
#################################

# Edit the siteConfig.xml found in any site within the sites folder - port and hostname
for SITE in  $gsdl3home/web/sites/*; do
    if [ -f $SITE/siteConfig.xml ] ; then
	echo "Processing $SITE"
	if [ "$hostname" != "localhost" ] ; then
	    sed "s|localhost|${hostname}|" $SITE/siteConfig.xml > $SITE/siteConfig.tmp && mv $SITE/siteConfig.tmp $SITE/siteConfig.xml
	fi
	if [ "$portnumber" != "8080" ] ; then
	    sed "s|8080|${portnumber}|" $SITE/siteConfig.xml > $SITE/siteConfig.tmp && mv $SITE/siteConfig.tmp $SITE/siteConfig.xml
	fi
    fi
done

############################
# GSDL3 SCRIPTS
#############################

# We also edit the GSDL3 launching script and the SOAP deployment script
cp gs3-launch.sh.in gs3-launch.sh
cp gs3-soap-deploy-site.sh.in gs3-soap-deploy-site.sh

if [ "$hostname" != "localhost" ] ; then
    sed "s|localhost|${hostname}|" gs3-launch.sh > gs3-launch.tmp && mv gs3-launch.tmp gs3-launch.sh
    sed "s|localhost|${hostname}|" gs3-soap-deploy-site.sh > gs3-soap.tmp && mv gs3-soap.tmp gs3-soap-deploy-site.sh
    
fi
if [ "$portnumber" != "8080" ] ; then
    sed "s|8080|${portnumber}|" gs3-launch.sh > gs3-launch.tmp && mv gs3-launch.tmp gs3-launch.sh
    sed "s|8080|${portnumber}|" gs3-soap-deploy-site.sh > gs3-soap.tmp && mv gs3-soap.tmp gs3-soap-deploy-site.sh
fi

# Make them executable
chmod a+x gs3-launch.sh
chmod a+x gs3-soap-deploy-site.sh

############################
# UNPACK SAMPLE COLLECTIONS
############################
 
# how can we stop these being done more than once? and do we need to?
cd web/sites/localsite/collect
# unpack import, index and metadata
for f in */index; do
  cd $f
  if test -f index.zip; then
    unzip index.zip
  fi
  cd ../../
done

for f in *; do
  cd $f
  if test -f import.zip; then
    unzip import.zip
  fi
  if test -f archives.zip; then
      unzip archives.zip
  fi
  if test -f metadata.zip; then
      unzip metadata.zip
  fi
  cd ../
done

cd $gsdl3home

#######################
# COMPILATION
######################

echo "############################################################"
echo "Will now configure and make the code - this may take a while"
echo "############################################################"

./configure
make
make install
make docs

# compile the test servlet
cd $gsdl3home/web/WEB-INF/classes
javac TestServlet.java
cd $gsdl3home

#######################
# COPY JAR FILES
#######################

# any jar files used by applets need to go into the web/lib directory. so we link to them
cd $gsdl3home/web/lib
ln -sf ../../lib/java/phind.jar
ln -sf ../../lib/java/xml-apis.jar
ln -sf ../../lib/java/xercesImpl.jar
cd $gsdl3home



# And provide a nice little postscript
echo ""
echo "****************************************************************"
echo "Greenstone 3 - Installation Complete!"
echo ""
echo "Run ./gs3-launch.sh to start the web server"
echo ""
echo "****************************************************************"
echo ""

exit 0
